@@ -25,7 +25,7 @@ class Configuration(metaclass=PoolMeta):
         pool = Pool()
         Company = pool.get('company.company')
         company_id = Transaction().context.get('company')
-        if company_id:
+        if company_id is not None and company_id >= 0:
             company = Company(company_id)
             return company.currency.digits
 
